@@ -3,7 +3,7 @@
  *
  * This file is part of msmtp, an SMTP client.
  *
- * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011
+ * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  * Martin Stenberg <martin@gnutiken.se> (passwordeval support)
  * Scott Shumate <sshumate@austin.rr.com> (aliases support)
@@ -1635,7 +1635,7 @@ int read_conffile(const char *conffile, FILE *f, list_t **acc_list,
             }
             else
             {
-                acc->aliases = xstrdup(arg);
+                acc->aliases = expand_tilde(arg);
             }
         }
         else if (strcmp(cmd, "tls_nocertcheck") == 0)
